@@ -59,8 +59,14 @@ class Gzip:
                 self.success_f.write(f'{filepath}\n')
                 print(f'{filepath} 解压完成')
                 success_count += 1
+            except EOFError as e:
+                self.error_f.write(f'{filepath}\t{e}\n')
+                self.error_f.flush()
+                print(f'{filepath} 解压失败，该文件结尾终止符缺失，文件不完整，请重新下载。')
+                error_count += 1
             except Exception as e:
                 self.error_f.write(f'{filepath}\t{e}\n')
+                self.error_f.flush()
                 print(f'{filepath} 解压失败', e)
                 error_count += 1
         print(f'本次共解压文件: {success_count + error_count}  解压成功: {success_count}  解压失败: {error_count}')
