@@ -158,15 +158,16 @@ class GeoDownloader:
 
         return request_list
 
-    def download_series_matrix_url(self, accession_list: Iterable = None, series_matrix_url_filepath: str = None,
-                                   async_on: bool = False):
+    def download_series_matrix_url(self, accession_list: Iterable = None, async_on: bool = False):
+        self.success_filepath = f'{self.history_dir}/success_url_accessions.txt'
+        self.error_filepath = f'{self.history_dir}/error_url_accessions.txt'
+
         if accession_list and type(accession_list) != set:
             accession_list = set(accession_list)
         elif self.accession_list:
             accession_list = self.accession_list
         else:
             raise Exception("accession_list can't is None")
-        self.series_matrix_url_filepath = series_matrix_url_filepath if series_matrix_url_filepath else f'{self.history_dir}/series_matrix_urls.txt'
         self.series_matrix_url_f = open(self.series_matrix_url_filepath, mode='a')
         while True:
             print('-*-' * 22)
@@ -242,13 +243,23 @@ class GeoDownloader:
         except Exception as e:
             print(f'{accession} 请求失败', e)
 
-    def download_series_matrix_init(self, series_matrix_url_filepath: str = None):
+    def download_series_matrix_init(self, series_matrix_url_filepath: str = None, series_matrix_urls: Iterable = None):
         """ 下载series_matrix 初始化 """
-        if not series_matrix_url_filepath:
-            self.download_series_matrix_url()
-        self.series_matrix_url_filepath = series_matrix_url_filepath if series_matrix_url_filepath else f'{self.history_dir}/series_matrix_urls.txt'
-        with open(self.series_matrix_url_filepath, mode='r') as f:
-            url_list = {line.strip() for line in f}
+        if series_matrix_urls:
+            url_list = series_matrix_urls if type(series_matrix_urls) == set else set(series_matrix_urls)
+        else:
+            if not series_matrix_url_filepath:
+                self.series_matrix_url_filepath = f'{self.history_dir}/series_matrix_urls.txt'
+                success_filepath = self.success_filepath
+                error_filepath = self.error_filepath
+                self.download_series_matrix_url()
+                self.success_filepath = success_filepath
+                self.error_filepath = error_filepath
+            else:
+                self.series_matrix_url_filepath = series_matrix_url_filepath
+            with open(self.series_matrix_url_filepath, mode='r') as f:
+                url_list = {line.strip() for line in f}
+
         return self.filter_request_list(request_list=url_list, desc='url')
 
     def download_series_matrix(self, url):
@@ -425,6 +436,7 @@ class GeoParser:
             df.to_csv(self.save_filename, index=False, encoding='utf_8_sig')
         for filepath in df['series_matrix_filepath']:
             self.success_f.write(f'{filepath}\n')
+        print(f'数据已保存至 {self.parse_dir} 文件夹')
 
     @Timeit("解析结束")
     def run(self, data_type, workers: int = None, save_filename: str = None, *args, **kwargs):
@@ -444,6 +456,7 @@ class GeoParser:
             raise Exception('init func or file_list must one is not None!')
 
         if len(file_list) > 0:
+            print('开始解析')
             workers = workers if workers else os.cpu_count()
             with ThreadPoolExecutor(max_workers=workers) as pool:
                 futures_list = (pool.submit(func_execute, file) for file in file_list)
